@@ -1,4 +1,5 @@
-package JMAP::Tester::LogWriter 0.102;
+use v5.14.0;
+package JMAP::Tester::LogWriter 0.103;
 
 use Moo::Role;
 
@@ -7,7 +8,7 @@ requires 'write';
 use namespace::clean;
 
 {
-  package JMAP::Tester::LogWriter::Code 0.102;
+  package JMAP::Tester::LogWriter::Code 0.103;
 
   use Moo;
   use namespace::clean;
@@ -17,7 +18,7 @@ use namespace::clean;
 }
 
 {
-  package JMAP::Tester::LogWriter::Handle 0.102;
+  package JMAP::Tester::LogWriter::Handle 0.103;
 
   use Moo;
   use namespace::clean;
@@ -27,7 +28,7 @@ use namespace::clean;
 }
 
 {
-  package JMAP::Tester::LogWriter::Filename 0.102;
+  package JMAP::Tester::LogWriter::Filename 0.103;
 
   use Moo;
   use namespace::clean;
@@ -71,15 +72,25 @@ JMAP::Tester::LogWriter
 
 =head1 VERSION
 
-version 0.102
+version 0.103
+
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by FastMail, Ltd.
+This software is copyright (c) 2016 by Fastmail Pty. Ltd.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
