@@ -1,6 +1,6 @@
-use v5.10.0;
+use v5.14.0;
 
-package JMAP::Tester::Response 0.102;
+package JMAP::Tester::Response 0.103;
 # ABSTRACT: what you get in reply to a succesful JMAP request
 
 use Moo;
@@ -95,7 +95,7 @@ JMAP::Tester::Response - what you get in reply to a succesful JMAP request
 
 =head1 VERSION
 
-version 0.102
+version 0.103
 
 =head1 OVERVIEW
 
@@ -105,13 +105,23 @@ call.  It is a successful L<JMAP::Tester::Result>.
 A Response is used mostly to contain the responses to the individual methods
 passed in the request.
 
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by FastMail, Ltd.
+This software is copyright (c) 2016 by Fastmail Pty. Ltd.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
