@@ -1,5 +1,5 @@
-use v5.10.0;
-package JMAP::Tester::Response::Sentence 0.102;
+use v5.14.0;
+package JMAP::Tester::Response::Sentence 0.103;
 # ABSTRACT: a single triple within a JMAP response
 
 use Moo;
@@ -135,7 +135,7 @@ JMAP::Tester::Response::Sentence - a single triple within a JMAP response
 
 =head1 VERSION
 
-version 0.102
+version 0.103
 
 =head1 OVERVIEW
 
@@ -154,6 +154,16 @@ The first item in the triple is accessed with the C<name> method.  The second
 is accessed with the C<arguments> method.  The third, with the C<client_id>
 method.
 
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 METHODS
 
 =head2 as_triple
@@ -192,11 +202,11 @@ returns the sentence.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by FastMail, Ltd.
+This software is copyright (c) 2016 by Fastmail Pty. Ltd.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
