@@ -1,7 +1,6 @@
-use v5.10.0;
-use strict;
+use v5.14.0;
 
-package JMAP::Tester::Result::Auth 0.102;
+package JMAP::Tester::Result::Auth 0.103;
 # ABSTRACT: what you get when you authenticate
 
 use Moo;
@@ -40,13 +39,23 @@ JMAP::Tester::Result::Auth - what you get when you authenticate
 
 =head1 VERSION
 
-version 0.102
+version 0.103
 
 =head1 OVERVIEW
 
 This is what you get when you authenticate!  It's got an C<is_success> method.
 It returns true. It also has:
 
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 METHODS
 
 =head2 client_session
@@ -55,11 +64,11 @@ The client session struct
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by FastMail, Ltd.
+This software is copyright (c) 2016 by Fastmail Pty. Ltd.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
