@@ -1,7 +1,6 @@
-use v5.10.0;
-use strict;
+use v5.14.0;
 
-package JMAP::Tester::Result::Failure 0.102;
+package JMAP::Tester::Result::Failure 0.103;
 # ABSTRACT: what you get when your JMAP request utterly fails
 
 use Moo;
@@ -41,7 +40,7 @@ JMAP::Tester::Result::Failure - what you get when your JMAP request utterly fail
 
 =head1 VERSION
 
-version 0.102
+version 0.103
 
 =head1 OVERVIEW
 
@@ -51,6 +50,16 @@ future.
 
 It's got an C<is_success> method.  It returns false. It also has:
 
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 METHODS
 
 =head2 ident
@@ -59,11 +68,11 @@ An error identifier. May or may not be defined.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by FastMail, Ltd.
+This software is copyright (c) 2016 by Fastmail Pty. Ltd.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
