@@ -1,7 +1,6 @@
-use v5.10.0;
-use strict;
+use v5.14.0;
 
-package JMAP::Tester::Result::Upload 0.102;
+package JMAP::Tester::Result::Upload 0.103;
 # ABSTRACT: what you get when you upload a blob
 
 use Moo;
@@ -24,8 +23,8 @@ use namespace::clean;
 #pod
 #pod =method type
 #pod
-#pod The media type of the file (as specified in RFC6838, section 4.2) as 
-#pod set in the Content-Type header of the upload HTTP request.
+#pod The media type of the file (as specified in RFC6838, section 4.2) as set in the
+#pod Content-Type header of the upload HTTP request.
 #pod
 #pod =method size
 #pod
@@ -58,13 +57,23 @@ JMAP::Tester::Result::Upload - what you get when you upload a blob
 
 =head1 VERSION
 
-version 0.102
+version 0.103
 
 =head1 OVERVIEW
 
 This is what you get when you upload!  It's got an C<is_success> method.  It
 returns true. It also has:
 
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 METHODS
 
 =head2 blob_id
@@ -77,8 +86,8 @@ An alias for C<blob_id> above.
 
 =head2 type
 
-The media type of the file (as specified in RFC6838, section 4.2) as 
-set in the Content-Type header of the upload HTTP request.
+The media type of the file (as specified in RFC6838, section 4.2) as set in the
+Content-Type header of the upload HTTP request.
 
 =head2 size
 
@@ -86,11 +95,11 @@ The size of the file in octets.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by FastMail, Ltd.
+This software is copyright (c) 2016 by Fastmail Pty. Ltd.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
