@@ -1,6 +1,6 @@
-use v5.10.0;
+use v5.14.0;
 use warnings;
-package JMAP::Tester::Role::HTTPResult 0.102;
+package JMAP::Tester::Role::HTTPResult 0.103;
 # ABSTRACT: the kind of thing that you get back for an http request
 
 use Moo::Role;
@@ -49,7 +49,7 @@ JMAP::Tester::Role::HTTPResult - the kind of thing that you get back for an http
 
 =head1 VERSION
 
-version 0.102
+version 0.103
 
 =head1 OVERVIEW
 
@@ -59,6 +59,16 @@ L<JMAP::Tester::Role::Result>, this role provides C<http_response> to
 get at the underlying L<HTTP::Response> object. C<response_payload> will
 come from the C<as_string> method of that object.
 
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 METHODS
 
 =head2 response_payload
@@ -69,11 +79,11 @@ but other result types may exist that don't have an http_response...
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by FastMail, Ltd.
+This software is copyright (c) 2016 by Fastmail Pty. Ltd.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
